@@ -1,4 +1,4 @@
-Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s", LinLab = NULL) {
+Plot.PCA <- function(PC, Titles = matrix(NA,1,3), Color = "s", LinLab = NULL) {
   # Rotina para Plotar Graficos do Metodo PCA desenvolvida 
   # por Paulo Cesar Ossani em 11/2014
   
@@ -15,8 +15,9 @@ Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s", LinLab = NULL) {
   
   ##### INICIO - Informacoes usadas nos Graficos #####
   # Cria Titulos para os graficos caso nao existam
-  if (!is.character(Titles[1]) || is.na(Titles[1])) Titles[1] = c("Grafico Correspondente as Linhas (Observacoes)")
-  if (!is.character(Titles[2]) || is.na(Titles[2])) Titles[2] = c("Grafico Correspondente as Colunas (Variaveis)")
+  if (!is.character(Titles[1]) || is.na(Titles[1])) Titles[1] = c("Scree-plot das variancias dos componentes")
+  if (!is.character(Titles[2]) || is.na(Titles[2])) Titles[2] = c("Grafico Correspondente as Linhas (Observacoes)")
+  if (!is.character(Titles[3]) || is.na(Titles[3])) Titles[3] = c("Grafico Correspondente as Colunas (Variaveis)")
   
   Color  = ifelse(Color=="s","S",ifelse(Color=="n","N",Color))    # transforma em maiusculo
   
@@ -41,14 +42,14 @@ Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s", LinLab = NULL) {
   plot(1:length(PC$MatrixAutoVlr[,1]), PC$MatrixAutoVlr[,1], type = "b", 
        xlab = "Ordem dos componentes", 
        ylab = "Variancia",
-       main = "Scree-plot das variancias dos componentes")
+       main = Titles[1])
   ##### FIM - Scree-plot dos componentes #####
   
   ##### INICIO - Plotagem dos Dados das linhas #####
   plot(PC$MatrixEsc, # cria grafico para as coordenadas principais das linhas
        xlab = DescEixo1,  # Nomeia Eixo X
        ylab = DescEixo2,  # Nomeia Eixo Y
-       main = Titles[1],  # Titulo
+       main = Titles[2],  # Titulo
        asp = 1,           # Aspecto do Grafico
        pch = 15,          # Formato dos pontos 
        cex = 1,           # Tamanho dos pontos
@@ -66,7 +67,7 @@ Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s", LinLab = NULL) {
   plot(0,0, # cria grafico para as coordenadas das Correlacoes dos Componentes Principais com as Variaveis Originais
        xlab = DescEixo1, # Nomeia Eixo X
        ylab = DescEixo2, # Nomeia Eixo Y
-       main = Titles[2], # Titulo
+       main = Titles[3], # Titulo
        asp = 1,          # Aspecto do Grafico
        cex=0,            # Tamanho dos pontos
        xlim=c(-1.1,1.1), # Dimensao para as linhas do grafico
@@ -76,7 +77,7 @@ Plot.PCA <- function(PC, Titles = matrix(NA,1,2), Color = "s", LinLab = NULL) {
   
   abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
   
-  arrows(0,0,PC$MatrixCCP[1,],PC$MatrixCCP[2,], lty=1, code = 2, angle = 10, col = ifelse(Color=="S","Blue","Black")) # cria a seta apontando para cada coordenada principal
+  arrows(0,0,PC$MatrixCCP[1,],PC$MatrixCCP[2,], lty=1, code = 2, length = 0.08, angle = 25, col = ifelse(Color=="S","Red","Black")) # cria a seta apontando para cada coordenada principal
   
   #text(t(PC$MatrixCCP), cex=1, colnames(PC$MatrixCCP) , col = ifelse(Color=="S","Blue","Black"), pos = 3, xpd = TRUE)  # Coloca os nomes dos pontos das coordenadas principais
   LocLab(t(PC$MatrixCCP), cex=1, colnames(PC$MatrixCCP) , col = ifelse(Color=="S","Blue","Black"), xpd = TRUE)
